@@ -1,3 +1,5 @@
+import pkg_resources
+
 from .tsdata import clean_tsdata
 from .tsdata import read_header
 from .tsdata import read_tsdata
@@ -5,8 +7,4 @@ from .tsdata import resample_tsdata
 from .tsdata import Tsdata
 from .tsdata import tsdata_to_csv
 
-
-from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
-
+__version__ = pkg_resources.get_distribution("tsdataformat").version
\ No newline at end of file
